@@ -23,7 +23,7 @@ class Format(object):
 
     """The binary format information of the file.
 
-    As specified in the Corsika user manual, Section 10.2.1.
+    As specified in the CORSIKA user manual, Section 10.2.1.
 
     """
 
@@ -58,7 +58,7 @@ class RunHeader(object):
 
     """The run header sub-block
 
-    As specified in the Corsika user manual, Table 7.
+    As specified in the CORSIKA user manual, Table 7.
 
     """
 
@@ -152,22 +152,12 @@ class RunHeader(object):
 
         return thickness
 
-    def __str__(self):
-        return textwrap.dedent("""\
-            Run header:
-                id: {run_n}
-                date: {date}
-                version: {version}
-            """.format(run_n=self.run_number,
-                       date=self.date_start,
-                       version=self.version))
-
 
 class EventHeader(object):
 
     """The event header sub-block
 
-    As specified in the Corsika user manual, Table 8.
+    As specified in the CORSIKA user manual, Table 8.
 
     """
 
@@ -182,15 +172,22 @@ class EventHeader(object):
         self.first_interaction_altitude = subblock[6] * units.cm
         self.p_x = subblock[7] * units.GeV
         self.p_y = subblock[8] * units.GeV
-        self.p_z = - subblock[9] * units.GeV
+        self.p_z = - subblock[9] * units.GeV  # Same direction as axis
         self.zenith = subblock[10] * units.rad
 
-        # Corsika defines azimuth as the direction the shower points to
+        # CORSIKA coordinate conventions are shown in Figure 1 of the manual.
+        # CORSIKA defines azimuth as the direction the shower points to,
         # HiSPARC defines azimuth as the direction the shower comes from.
-        # Corsika allows azimuths in [-2pi, 2pi], HiSPARC uses (-pi, pi]
-        azimuth = subblock[11] * units.rad + math.pi
-        if azimuth > math.pi:
+        # CORSIKA allows azimuths in [-2pi, 2pi], HiSPARC uses [-pi, pi).
+        # CORSIKA defines North as 0 rad, HiSPARC defines East as 0 rad.
+        # So finally we need to subtract pi/2 rad from the azimuth and
+        # normalize its range.
+        azimuth_corsika = subblock[11] * units.rad
+        azimuth = azimuth_corsika - (math.pi / 2.)
+        if azimuth >= math.pi:
             self.azimuth = azimuth - (2 * math.pi)
+        elif azimuth < -math.pi:
+            self.azimuth = azimuth + (2 * math.pi)
         else:
             self.azimuth = azimuth
 
@@ -312,25 +309,12 @@ class EventHeader(object):
         computers = {3: 'UNIX', 4: 'Macintosh'}
         return computers.get(self.flag_computer, 'unknown')
 
-    def __str__(self):
-        return textwrap.dedent("""\
-            Event header:
-                id: {event_n}
-                primary: {primary}
-                energy: {energy} EeV
-                direction: ({zenith}, {azimuth})
-            """.format(event_n=self.event_number,
-                       primary=self.particle_id,
-                       energy=self.energy / units.EeV,
-                       zenith=self.zenith / units.degree,
-                       azimuth=self.azimuth / units.degree))
-
 
 class RunEnd(object):
 
     """The run end sub-block
 
-    As specified in the Corsika user manual, Table 14.
+    As specified in the CORSIKA user manual, Table 14.
 
     """
 
@@ -339,20 +323,12 @@ class RunEnd(object):
         self.run_number = subblock[1]
         self.n_events_processed = subblock[2]
 
-    def __str__(self):
-        return textwrap.dedent("""\
-            Run end:
-                id: {run_number}
-                events: {n_events}
-            """.format(run_number=self.run_number,
-                       n_events=self.n_events_processed))
-
 
 class EventEnd(object):
 
     """The event end sub-block
 
-    As specified in the Corsika user manual, Table 13.
+    As specified in the CORSIKA user manual, Table 13.
 
     """
 
@@ -398,31 +374,32 @@ class EventEnd(object):
         self.n_muons_output = subblock[265]
         self.n_preshower_EM_particles = subblock[266]
 
-    def __str__(self):
-        return textwrap.dedent("""\
-            Event end:
-                id: {event_n}
-                particles: {particles}
-            """.format(event_n=self.event_number,
-                       particles=self.n_particles_levels))
-
 
 def particle_data(subblock):
     """Get particle data.
 
-    High-performing version of the ParticleData class, but without all the
-    easy-to-use attribute access.
+    As specified in the CORSIKA user manual, Table 10. High-performing
+    version of the ParticleData class, but without all the easy-to-use
+    attribute access.
+
+    Transformations are needed for the x, y and p_z values from CORSIKA.
+    CORSIKA coordinate conventions are mentioned in Figure 1 and Table 10.
 
     :returns: tuple with p_x, p_y, p_z, x, y, t, id, r, hadron_generation,
-        observation_level, phi data.
+              observation_level, phi data.
 
     """
+    # These three are subject to coordinate transformations
+    x_corsika = subblock[4] * units.cm
+    y_corsika = subblock[5] * units.cm
+    p_z_corsika = subblock[3] * units.GeV
+
     description = int(subblock[0])
     p_x = subblock[1] * units.GeV
     p_y = subblock[2] * units.GeV
-    p_z = - subblock[3] * units.GeV
-    x = subblock[4] * units.cm
-    y = subblock[5] * units.cm
+    p_z = -p_z_corsika
+    x = -y_corsika
+    y = x_corsika
     t = subblock[6] * units.ns  # or z for additional muon info
 
     id = description / 1000
@@ -440,37 +417,31 @@ class ParticleData(object):
 
     """The particle data sub-block
 
-    As specified in the Corsika user manual, Table 10.
+    As specified in the CORSIKA user manual, Table 10.
 
     """
 
     def __init__(self, subblock):
-        self.description = int(subblock[0])
-        self.p_x = subblock[1] * units.GeV
-        self.p_y = subblock[2] * units.GeV
-        self.p_z = - subblock[3] * units.GeV
-        self.x = subblock[4] * units.cm
-        self.y = subblock[5] * units.cm
-        self.t = subblock[6] * units.ns  # or z for additional muon info
-
-        self.id = self.description / 1000
-        self.r = math.sqrt(self.x ** 2 + self.y ** 2)
-        self.is_particle = 0 < self.id < 200
-        self.particle = particles.name(self.id) if self.is_particle else None
-        self.is_detectable = self.particle in ['positron', 'electron',
-                                               'muon_p', 'muon_m']  # + 'gamma'
+        self.p_x, self.p_y, self.p_z, self.x, self.y, self.t, self.id, \
+            self.r, self.hadron_generation, self.observation_level, \
+            self.phi = particle_data(subblock)
 
     @property
-    def hadron_generation(self):
-        return self.description / 10 % 100
+    def is_detectable(self):
+        """Get True or False if the particle is detectable
+
+        Note: gamma particles are currently not included.
+
+        """
+        return self.particle in ['positron', 'electron', 'muon_p', 'muon_m']
 
     @property
-    def observation_level(self):
-        return self.description % 10
+    def particle(self):
+        return particles.name(self.id) if self.is_particle else None
 
     @property
-    def phi(self):
-        return math.atan2(self.y, self.x)
+    def is_particle(self):
+        return 0 < self.id < 200
 
     @property
     def is_nucleus(self):
@@ -497,26 +468,12 @@ class ParticleData(object):
         else:
             return None
 
-    def __str__(self):
-        return textwrap.dedent("""\
-            Particle:
-                description: {description}
-                momentum: {momentum} GeV
-                position: {position} m
-                time: {time} ns
-            """.format(description=self.description,
-                       momentum=(self.p_x / units.GeV,
-                                 self.p_y / units.GeV,
-                                 self.p_z / units.GeV),
-                       position=(self.x / units.m, self.y / units.m),
-                       time=self.t / units.ns))
-
 
 class CherenkovData(object):
 
     """The cherenkov photon sub-block
 
-    As specified in Corsika user manual, Table 11.
+    As specified in CORSIKA user manual, Table 11.
 
     The number of CherenkovData records in a sub-block depends on
     compilation options.
@@ -532,20 +489,6 @@ class CherenkovData(object):
         self.t = subblock[5] * units.ns
         self.production_height = subblock[6] * units.cm
 
-    def __str__(self):
-        return textwrap.dedent("""\
-            Cherenkov:
-                n: {n}
-                position: {position} m
-                (u,v): {direction}
-                time: {time} ns
-                prod. height: {height} m
-            """.format(n=self.photons_in_bunch,
-                       direction=(self.u, self.v),
-                       position=(self.x / units.m, self.y / units.m),
-                       time=self.t / units.ns,
-                       height=self.production_height / units.m))
-
 
 # THIN versions
 
@@ -553,7 +496,7 @@ class FormatThin(Format):
 
     """The format information of the thinned file
 
-    As specified in Corsika user manual, Section 10.2.2.
+    As specified in CORSIKA user manual, Section 10.2.2.
 
     """
 
@@ -582,7 +525,7 @@ class ParticleDataThin(ParticleData):
 
     """The thinned particle data sub-block
 
-    As specified in the Corsika user manual, Table 10.
+    As specified in the CORSIKA user manual, Table 10.
 
     """
 
@@ -590,28 +533,12 @@ class ParticleDataThin(ParticleData):
         self.weight = subblock[7]
         super(ParticleDataThin, self).__init__(subblock)
 
-    def __str__(self):
-        return textwrap.dedent("""\
-            Particle:
-                id: {description}
-                momentum: {momentum} GeV
-                position: {position} m
-                time: {time} ns
-                weight: {weight}
-            """.format(description=self.description,
-                       momentum=(self.p_x / units.GeV,
-                                 self.p_y / units.GeV,
-                                 self.p_z / units.GeV),
-                       position=(self.x / units.m, self.y / units.m),
-                       time=self.t / units.ns,
-                       weight=self.weight))
-
 
 class CherenkovDataThin(CherenkovData):
 
     """The thinned cherenkov photon sub-block
 
-    As specified in Corsika user manual, Table 11.
+    As specified in CORSIKA user manual, Table 11.
 
     The number of CherenkovData records in a sub-block depends on
     compilation options.
@@ -621,19 +548,3 @@ class CherenkovDataThin(CherenkovData):
     def __init__(self, subblock):
         self.weight = subblock[7]
         super(CherenkovDataThin, self).__init__(subblock)
-
-    def __str__(self):
-        return textwrap.dedent("""\
-            Cherenkov:
-                n: {n}
-                position: {position} m
-                (u,v): {direction}
-                time: {time} ns
-                prod. height: {height} m
-                weight: {weight}
-            """.format(n=self.photons_in_bunch,
-                       direction=(self.u, self.v),
-                       position=(self.x / units.m, self.y / units.m),
-                       time=self.t / units.ns,
-                       height=self.production_height / units.m,
-                       weight=self.weight))
