@@ -1,6 +1,8 @@
 import unittest
 import datetime
 
+from mock import patch
+
 from sapphire import time_util
 
 
@@ -19,6 +21,15 @@ class GPSTimeUtilTests(unittest.TestCase):
         self.assertRaises(TypeError, time_util.GPSTime)
         self.assertRaises(TypeError, time_util.GPSTime, 2012, 12)
 
+    @patch.object(time_util.GPSTime, 'description')
+    def test_str_returns_description(self, mock_description):
+        expected = "Foobar"
+        mock_description.return_value = expected
+        t = time_util.GPSTime(2014, 10, 27)
+        actual = str(t)
+        mock_description.assert_called_once_with()
+        self.assertIs(actual, expected)
+
 
 if __name__ == '__main__':
     unittest.main()
